package com.grupo.proyectoescuela.modelo;

import javax.persistence.*;

/**
 * Modelo para representar un estudiante.
 * Este modelo está mapeado como una entidad en la base de datos.
 */
@Entity
public class Estudiante {

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    /**
     * Identificador único del estudiante.
     */
    private Long id;

    /**
     * Nombre del estudiante.
     */
    private String nombre;

    /**
     * Correo electrónico del estudiante.
     */
    private String email;

    /**
     * Constructor sin parámetros.
     * Es requerido por Hibernate.
     */
    public Estudiante() {
    }

    /**
     * Constructor para crear un nuevo estudiante con nombre y correo electrónico.
     *
     * @param nombre nombre del estudiante
     * @param email  correo electrónico del estudiante
     */
    public Estudiante(String nombre, String email) {
        this.nombre = nombre;
        this.email = email;
    }

    /**
     * Devuelve el identificador del estudiante.
     *
     * @return el identificador del estudiante
     */
    public Long getId() {
        return id;
    }

    /**
     * Establece el identificador del estudiante.
     *
     * @param id el nuevo identificador del estudiante
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * Devuelve el nombre del estudiante.
     *
     * @return el nombre del estudiante
     */
    public String getNombre() {
        return nombre;
    }

    /**
     * Establece el nombre del estudiante.
     *
     * @param nombre el nuevo nombre del estudiante
     */
    public void setNombre(String nombre) {
        this.nombre = nombre;
    }

    /**
     * Devuelve el correo electrónico del estudiante.
     *
     * @return el correo electrónico del estudiante
     */
    public String getEmail() {
        return email;
    }

    /**
     * Establece el correo electrónico del estudiante.
     *
     * @param email el nuevo correo electrónico del estudiante
     */
    public void setEmail(String email) {
        this.email = email;
    }
}
