package com.grupo.proyectoescuela.modelo;

import javax.persistence.*;

/**
 * Modelo para representar una nota.
 * Este modelo está mapeado como una entidad en la base de datos.
 */
@Entity
public class Nota {

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    /**
     * Identificador único de la nota.
     */
    private Long id;

    @ManyToOne
    /**
     * Estudiante al que pertenece esta nota.
     * Esto establece una relación muchos-a-uno entre Nota y Estudiante.
     */
    private Estudiante estudiante;

    /**
     * Valor de la nota.
     */
    private Double nota;

    /**
     * Constructor sin parámetros.
     * Es requerido por Hibernate.
     */
    public Nota() {
    }

    /**
     * Constructor para crear una nueva nota con estudiante y valor.
     *
     * @param estudiante estudiante al que pertenece la nota
     * @param nota       valor de la nota
     */
    public Nota(Estudiante estudiante, Double nota) {
        this.estudiante = estudiante;
        this.nota = nota;
    }

    /**
     * Devuelve el identificador de la nota.
     *
     * @return el identificador de la nota
     */
    public Long getId() {
        return id;
    }

    /**
     * Establece el identificador de la nota.
     *
     * @param id el nuevo identificador de la nota
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * Devuelve el estudiante al que pertenece la nota.
     *
     * @return el estudiante al que pertenece la nota
     */
    public Estudiante getEstudiante() {
        return estudiante;
    }

    /**
     * Establece el estudiante al que pertenece la nota.
     *
     * @param estudiante el nuevo estudiante al que pertenece la nota
     */
    public void setEstudiante(Estudiante estudiante) {
        this.estudiante = estudiante;
    }

    /**
     * Devuelve el valor de la nota.
     *
     * @return el valor de la nota
     */
    public Double getNota() {
        return nota;
    }

    /**
     * Establece el valor de la nota.
     *
     * @param nota el nuevo valor de la nota
     */
    public void setNota(Double nota) {
        this.nota = nota;
    }
}
