package com.grupo.proyectoescuela.servicio;

import com.grupo.proyectoescuela.modelo.Nota;
import com.grupo.proyectoescuela.repositorio.NotaRepositorio;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * Servicio para manejar las operaciones relacionadas con las notas.
 * Proporciona métodos para obtener, guardar y eliminar notas.
 */
@Service
public class NotaServicio {

    private final NotaRepositorio notaRepositorio;

    /**
     * Constructor con inyección de dependencias para el repositorio necesario.
     *
     * @param notaRepositorio repositorio para manejar operaciones relacionadas con las notas
     */
    @Autowired
    public NotaServicio(NotaRepositorio notaRepositorio) {
        this.notaRepositorio = notaRepositorio;
    }

    /**
     * Método para obtener todas las notas.
     *
     * @return una lista de todas las notas
     */
    public List<Nota> obtenerTodasLasNotas() {
        return notaRepositorio.findAll();
    }

    /**
     * Método para obtener una nota por su id.
     *
     * @param id el id de la nota
     * @return la nota si se encuentra, o null si no se encuentra
     */
    public Nota obtenerNotaPorId(Long id) {
        return notaRepositorio.findById(id).orElse(null);
    }

    /**
     * Método para guardar una nota.
     *
     * @param nota la nota a guardar
     * @return la nota guardada
     */
    public Nota guardarNota(Nota nota) {
        return notaRepositorio.save(nota);
    }

    /**
     * Método para eliminar una nota por su id.
     *
     * @param id el id de la nota a eliminar
     */
    public void eliminarNota(Long id) {
        notaRepositorio.deleteById(id);
    }
}
