package com.grupo.proyectoescuela.util;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.mail.SimpleMailMessage;
import org.springframework.mail.javamail.JavaMailSender;
import org.springframework.stereotype.Component;

/**
 * Utilidad para enviar emails.
 */
@Component
public class EmailUtil {

    private final JavaMailSender javaMailSender;

    /**
     * Constructor con inyección de dependencia para el servicio de envío de mails.
     *
     * @param javaMailSender el servicio de envío de mails
     */
    @Autowired
    public EmailUtil(JavaMailSender javaMailSender) {
        this.javaMailSender = javaMailSender;
    }

    /**
     * Método para enviar un correo electrónico.
     *
     * @param to el destinatario del correo electrónico
     * @param subject el asunto del correo electrónico
     * @param text el cuerpo del correo electrónico
     */
    public void sendEmail(String to, String subject, String text) {
        try {
            SimpleMailMessage simpleMailMessage = new SimpleMailMessage();
            simpleMailMessage.setFrom("jose.guillen@usm.cl");
            simpleMailMessage.setTo(to);
            simpleMailMessage.setSubject(subject);
            simpleMailMessage.setText(text);
            javaMailSender.send(simpleMailMessage);
        } catch (Exception e) {
            // Reemplaza esto con tu logger
            System.err.println("Error al enviar correo: " + e.getMessage());
            e.printStackTrace();
        }
    }

}
