/**
 * La clase Main es el punto de entrada de la aplicación JavaFX.
 * Extiende de la clase Application que es la clase base principal para todas las aplicaciones JavaFX.
 * El ciclo de vida de una aplicación JavaFX se maneja a través de varios métodos de la clase Application como init() y stop().
 * Aquí solo se sobrescribe el método start(), que es un método abstracto del ciclo de vida de una aplicación JavaFX.
 */
package com.grupo.proyectoescuela;

import javafx.application.Application;
import javafx.scene.Scene;
import javafx.stage.Stage;
import com.grupo.proyectoescuela.vista.VistaPrincipal;

public class Main extends Application {

    /**
     * El método start() se llama después de que se ha inicializado el método init().
     * Este método es abstracto y debe ser sobrescrito. 
     * Es el principal punto de entrada para todas las aplicaciones JavaFX.
     *
     * @param primaryStage el Stage primario para esta aplicación, sobre el cual se coloca la escena visual.
     * @throws Exception puede lanzar cualquier excepción que ocurra durante la ejecución del método.
     */
    @Override
    public void start(Stage primaryStage) throws Exception{
        VistaPrincipal vistaPrincipal = new VistaPrincipal();
        primaryStage.setTitle("Proyecto Escuela");
        Scene scene = new Scene(vistaPrincipal.crearVistaPrincipal(), 800, 600);
        scene.getStylesheets().add(getClass().getResource("estilos.css").toExternalForm());
        primaryStage.setScene(scene);
        primaryStage.show();
    }

    /**
     * Método main, el punto de entrada para todas las aplicaciones de Java.
     * La aplicación lanzará la interfaz de usuario utilizando el método estático launch() de la clase Application.
     *
     * @param args los argumentos de línea de comando.
     */
    public static void main(String[] args) {
        launch(args);
    }
}
