package com.grupo.proyectoescuela.controlador;

import com.grupo.proyectoescuela.modelo.Estudiante;
import com.grupo.proyectoescuela.modelo.Nota;
import com.grupo.proyectoescuela.util.ApiRequest;

import kong.unirest.Unirest;

import java.util.List;

/**
 * Controlador para las operaciones de las notas.
 * Se comunica con la API del backend para realizar operaciones CRUD sobre las notas.
 */
public class ControladorNota {

    private ApiRequest apiRequest = new ApiRequest();

    /**
     * Método para subir una nota a un estudiante utilizando la API del backend.
     *
     * @param estudianteId el ID del estudiante al que se le subirá la nota
     * @param nota la nota que se le subirá al estudiante
     */
    public void subirNota(int estudianteId, String nota) {

        Estudiante estudiante = new Estudiante();
        estudiante.setId(estudianteId);
        
        Nota notaObj = new Nota();
        notaObj.setEstudiante(estudiante);
        notaObj.setNota(nota);
        
        String json = Unirest.config().getObjectMapper().writeValue(notaObj);
        System.out.println(json);
        
        apiRequest.postRequest("http://localhost:8080/notas", notaObj);
    }

    /**
     * Método para obtener una lista de notas utilizando la API del backend.
     *
     * @return una lista de notas
     */
    public List<Nota> obtenerNotas() {
        List<Nota> notas = apiRequest.getRequest("http://localhost:8080/notas", Nota.class);
        System.out.println(notas);
        return notas;
    }

}
