/**
 * Clase Estudiante que representa una entidad estudiante en el sistema.
 * Cada estudiante tiene un nombre, un correo electrónico y una identificación única.
 */
package com.grupo.proyectoescuela.modelo;

public class Estudiante {

    private String nombre;
    private String email;
    private int id;

    /**
     * Constructor predeterminado necesario para las operaciones de serialización y deserialización.
     */
    public Estudiante() {}

    /**
     * Constructor que crea una nueva instancia de Estudiante con un nombre y correo electrónico especificados.
     * 
     * @param nombre Nombre del estudiante.
     * @param email Correo electrónico del estudiante.
     */
    public Estudiante(String nombre, String email) {
        this.nombre = nombre;
        this.email = email;
    }

    /**
     * Obtiene el nombre del estudiante.
     *
     * @return String que representa el nombre del estudiante.
     */
    public String getNombre() {
        return nombre;
    }

    /**
     * Establece el nombre del estudiante.
     *
     * @param nombre String que representa el nombre del estudiante.
     */
    public void setNombre(String nombre) {
        this.nombre = nombre;
    }

    /**
     * Obtiene el correo electrónico del estudiante.
     *
     * @return String que representa el correo electrónico del estudiante.
     */
    public String getEmail() {
        return email;
    }

    /**
     * Establece el correo electrónico del estudiante.
     *
     * @param email String que representa el correo electrónico del estudiante.
     */
    public void setEmail(String email) {
        this.email = email;
    }

    /**
     * Establece la identificación del estudiante.
     *
     * @param id Entero que representa la identificación del estudiante.
     */
    public void setId(int id) {
        this.id = id;
    }

    /**
     * Obtiene la identificación del estudiante.
     *
     * @return Entero que representa la identificación del estudiante.
     */
    public int getId() {
        return id;
    }

    // Otros getters y setters...
}
