/**
 * Clase Nota que representa una entidad de nota en el sistema.
 * Cada nota está asociada a un estudiante y tiene un ID de estudiante, 
 * una referencia al objeto estudiante y la nota propiamente dicha.
 */
package com.grupo.proyectoescuela.modelo;

public class Nota {
    private int estudiante_id;
    private String nota;
    private Estudiante estudiante;

    /**
     * Obtiene el objeto Estudiante asociado con la Nota.
     *
     * @return Objeto Estudiante que representa el estudiante al que está asociada la nota.
     */
    public Estudiante getEstudiante() {
        return estudiante;
    }

    /**
     * Establece el objeto Estudiante asociado a la Nota.
     *
     * @param estudiante Objeto Estudiante que representa el estudiante al que se asociará la nota.
     */
    public void setEstudiante(Estudiante estudiante) {
        this.estudiante = estudiante;
    }

    /**
     * Constructor predeterminado necesario para las operaciones de serialización y deserialización.
     */
    public Nota() {}

    /**
     * Constructor que crea una nueva instancia de Nota con un id de estudiante y una nota especificada.
     * 
     * @param estudianteId Identificación del estudiante a quien pertenece la nota.
     * @param nota Nota del estudiante.
     */
    public Nota(int estudianteId, String nota) {
        this.estudiante_id = estudianteId;
        this.nota = nota;
    }

    /**
     * Obtiene la identificación del estudiante al que pertenece la nota.
     *
     * @return Entero que representa la identificación del estudiante.
     */
    public int getEstudianteId() {
        return estudiante_id;
    }

    /**
     * Establece la identificación del estudiante al que pertenece la nota.
     *
     * @param estudianteId Entero que representa la identificación del estudiante.
     */
    public void setEstudianteId(int estudianteId) {
        this.estudiante_id = estudianteId;
    }

    /**
     * Obtiene la nota del estudiante.
     *
     * @return String que representa la nota del estudiante.
     */
    public String getNota() {
        return nota;
    }

    /**
     * Establece la nota del estudiante.
     *
     * @param nota String que representa la nota del estudiante.
     */
    public void setNota(String nota) {
        this.nota = nota;
    }

    /**
     * Obtiene la identificación de la nota.
     *
     * @return Entero que representa la identificación de la nota.
     */
    public int getId() {
        return estudiante_id;
    }

    /**
     * Establece la identificación de la nota.
     *
     * @param id Entero que representa la identificación de la nota.
     */
    public void setId(int id) {
        this.estudiante_id = id;
    }
}
