/**
 * La clase VistaEstudiante representa la interfaz gráfica de usuario para la vista de Estudiante.
 * Proporciona funcionalidades para mostrar la lista de estudiantes y para agregar nuevos estudiantes.
 * Utiliza JavaFX para crear la interfaz gráfica de usuario.
 */
package com.grupo.proyectoescuela.vista;

import com.grupo.proyectoescuela.controlador.ControladorEstudiante;
import com.grupo.proyectoescuela.modelo.Estudiante;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.geometry.Insets;
import javafx.scene.control.Button;
import javafx.scene.control.ListCell;
import javafx.scene.control.ListView;
import javafx.scene.control.TextField;
import javafx.scene.layout.VBox;
import javafx.scene.text.Text;

public class VistaEstudiante {

    /**
     * Crea y devuelve un VBox que contiene la interfaz de usuario de la vista de Estudiante.
     * El VBox contiene una lista de estudiantes y campos para agregar un nuevo estudiante.
     *
     * @return Un VBox que contiene la interfaz de usuario de la vista de Estudiante.
     */
    public VBox crearVistaEstudiante() {
        VBox vBox = new VBox();
        vBox.setPadding(new Insets(10));
        vBox.setSpacing(8);

        // Lista de estudiantes
        VBox vBoxLista = new VBox();
        vBoxLista.setMinWidth(300);
        vBoxLista.setSpacing(8);
        vBoxLista.setMinHeight(300);

        Text titleLista = new Text("Lista de Estudiantes");
        titleLista.setStyle("-fx-fill: white;");
        ObservableList<Estudiante> estudiantes = FXCollections.observableArrayList();
        ListView<Estudiante> listaEstudiantes = new ListView<>(estudiantes);

        ControladorEstudiante controlador = new ControladorEstudiante();
        estudiantes.addAll(controlador.obtenerEstudiantes());

        listaEstudiantes.setCellFactory(param -> new ListCell<Estudiante>() {
            @Override
            protected void updateItem(Estudiante estudiante, boolean empty) {
                super.updateItem(estudiante, empty);

                if (empty || estudiante == null) {
                    setText(null);
                } else {
                    // Aquí, se añade el ID del estudiante al texto
                    setText(estudiante.getId() + " - " + estudiante.getNombre() + " - " + estudiante.getEmail());
                }
            }
        });

        vBoxLista.getChildren().addAll(titleLista, listaEstudiantes);

        // Crear estudiante
        VBox vBoxCrear = new VBox();
        vBoxCrear.setSpacing(8);

        TextField nombreField = new TextField();
        nombreField.setPromptText("Nombre");
        TextField emailField = new TextField();
        emailField.setPromptText("Email");
        Button agregarButton = new Button("Agregar Estudiante");

        agregarButton.setOnAction(e -> {
            controlador.crearEstudiante(nombreField.getText(), emailField.getText());
            estudiantes.setAll(controlador.obtenerEstudiantes());
        });

        vBoxCrear.getChildren().addAll(nombreField, emailField, agregarButton);

        vBox.getChildren().addAll(vBoxLista, vBoxCrear);

        return vBox;
    }
}
