/**
 * La clase VistaNota representa la interfaz gráfica de usuario para la vista de Nota.
 * Proporciona funcionalidades para mostrar la lista de notas y para agregar nuevas notas a los estudiantes.
 * Utiliza JavaFX para crear la interfaz gráfica de usuario.
 */
package com.grupo.proyectoescuela.vista;

import com.grupo.proyectoescuela.controlador.ControladorNota;
import com.grupo.proyectoescuela.modelo.Nota;
import javafx.geometry.Insets;
import javafx.scene.control.Button;
import javafx.scene.control.ListCell;
import javafx.scene.control.ListView;
import javafx.scene.control.TextField;
import javafx.scene.layout.VBox;
import javafx.scene.text.Text;

public class VistaNota {

    /**
     * Crea y devuelve un VBox que contiene la interfaz de usuario de la vista de Nota.
     * El VBox contiene una lista de notas y campos para agregar una nueva nota a un estudiante.
     *
     * @return Un VBox que contiene la interfaz de usuario de la vista de Nota.
     */
    public VBox crearVistaNota() {
        VBox vBox = new VBox();
        vBox.setPadding(new Insets(10));
        vBox.setSpacing(8);
        VBox vBoxLista = new VBox();
        vBoxLista.setSpacing(8);
        vBoxLista.setMinHeight(300);

        Text title = new Text("Notas");
        title.setStyle("-fx-fill: white;");
        ListView<Nota> listaNotas = new ListView<>();
        TextField estudianteIdField = new TextField();
        estudianteIdField.setPromptText("ID de estudiante");
        TextField notaField = new TextField();
        notaField.setPromptText("Nota");
        Button subirButton = new Button("Subir Nota");

        ControladorNota controlador = new ControladorNota();
        subirButton.setOnAction(e -> {
            String estudianteIdText = estudianteIdField.getText();
            if (estudianteIdText == null || estudianteIdText.isEmpty()) {
                // Mostrar un mensaje de error o hacer algo más apropiado
                System.out.println("Por favor, introduce una ID de estudiante.");
            } else {
                try {
                    int estudianteId = Integer.parseInt(estudianteIdText);
                    controlador.subirNota(estudianteId, notaField.getText());
                    // Actualizar la lista de notas después de subir una nota
                    listaNotas.getItems().setAll(controlador.obtenerNotas());
                } catch (NumberFormatException ex) {
                    // Mostrar un mensaje de error o hacer algo más apropiado
                    System.out.println("La ID del estudiante debe ser un número entero.");
                }
            }
        });


        // Crear un CellFactory personalizado para mostrar los datos de Nota en el ListView
        listaNotas.setCellFactory(param -> new ListCell<>() {
            @Override
            protected void updateItem(Nota nota, boolean empty) {
                super.updateItem(nota, empty);
                if (empty || nota == null) {
                    setText(null);
                } else {
                    // Mostrar los datos relevantes de la nota en la lista
                    setText("Estudiante: " + nota.getEstudiante().getNombre() +
                            ", Nota: " + nota.getNota());
                }
            }
        });

        listaNotas.getItems().addAll(controlador.obtenerNotas());

        vBox.getChildren().addAll(title, listaNotas, estudianteIdField, notaField, subirButton);

        return vBox;
    }
}
